import React from 'react';
import PropTypes from 'prop-types';

import { DatePicker as DatePickerMaterial } from 'material-ui-pickers';
import DateFnsUtils from 'material-ui-pickers/utils/date-fns-utils';
import MuiPickersUtilsProvider from 'material-ui-pickers/utils/MuiPickersUtilsProvider';

import locales from 'date-fns/locale';


import { getErrors, getLocale } from '../helpers/inputHelpers';

const DatePicker = ({
  onChange, value, label, innerState, messages, format, locale, okLabel, cancelLabel,
}) => {
  const localeUtil = getLocale(locale, locales);
  const errors = getErrors({ innerState, messages });
  const isErr = !!errors.length;

  return (
    <MuiPickersUtilsProvider utils={DateFnsUtils} locale={localeUtil}>
      <DatePickerMaterial
        fullWidth={true}
        error={isErr}
        helperText={errors || ' '}
        onChange={value => onChange(`${value}`)}
        format={format}
        invalidLabel=''
        value={value}
        label={label}
        okLabel={okLabel}
        cancelLabel={cancelLabel}
        />
    </MuiPickersUtilsProvider>

  );
};

DatePicker.propTypes = {
  onChange: PropTypes.func,
  value: PropTypes.string,
  label: PropTypes.string,
  messages: PropTypes.object,
  format: PropTypes.string,
  locale: PropTypes.string,
  okLabel: PropTypes.string,
  cancelLabel: PropTypes.string,
};

export default DatePicker;
