import React from 'react';
import PropTypes from 'prop-types';

import { connect } from 'react-redux';
import { actions } from 'react-redux-form';

import { FormControl, FormHelperText, MenuItem, InputLabel } from '@material-ui/core';
import SelectMaterial from '@material-ui/core/Select';

import { getErrors } from '../helpers/inputHelpers';


const mapDispatchToProps = dispatch => ({
  setValue: (name, value) => dispatch(actions.change(name, value)),
});

const enhance = connect(null, mapDispatchToProps);

class Select extends React.Component {
  handleChange = (event) => {
    const { name, setValue } = this.props;
    setValue(name, event.target.value);
  }

  render() {
    const {
      label, helperText, innerState,
      messages, value = '', options,
      optionsSelector, MenuProps, fullWidth,
      style, className,
    } = this.props;
    let errors = getErrors({ innerState, messages });
    let isDisabled = false;
    const isErr = !!errors.length;
    if (!options.length) {
      errors = 'Нет доступных вариантов';
      isDisabled = true;
    }
    return (
      <FormControl fullWidth={fullWidth} error={isErr} style={style} disabled={isDisabled} className={className || ''}>
        <InputLabel>{label}</InputLabel>
        <SelectMaterial
          value={value}
          onChange={this.handleChange}
          MenuProps={{
            ...MenuProps,
            onEnter: () => { // https://github.com/mui-org/material-ui/issues/10601#issuecomment-377603492
            setTimeout(() => {
              if (document.activeElement) {
                document.activeElement.blur();
              }
            }, 500);
          },
}}>
          {(optionsSelector ? optionsSelector(options) : options).map(option =>
            <MenuItem key={option.key || option.value} value={option.value}>
              {option.label}
            </MenuItem>)
          }
        </SelectMaterial>
        <FormHelperText>{isErr || isDisabled ? errors : helperText || ' '}</FormHelperText>
      </FormControl>
    );
  }
}

Select.propTypes = {
  placeholder: PropTypes.string,
  helperText: PropTypes.string,
  innerState: PropTypes.object,
  messages: PropTypes.object,
  value: PropTypes.string,
  options: PropTypes.array,
  optionsSelector: PropTypes.func,
  MenuProps: PropTypes.object,
  fullWidth: PropTypes.bool,
  style: PropTypes.object,
};

export default enhance(Select);
