import React from 'react';
import PropTypes from 'prop-types';

import TextFieldMaterial from '@material-ui/core/TextField';
import NumberFormat from 'react-number-format';
import { getErrors } from '../helpers/inputHelpers';

const BaseTextField = ({
  placeholder,
  helperText,
  innerState,
  messages,
  mask,
  name,
  label,
  helperTextOff,
  ...props
}) => {
  let helperMsg;
  const errors = getErrors({ innerState, messages });
  const isErr = !!errors.length;
  if (helperTextOff) {
    helperMsg = null;
  } else if (isErr) {
    helperMsg = errors;
  } else {
    helperMsg = ' ';
  }
  return (<TextFieldMaterial
    id={name}
    fullWidth={true}
    label={label}
    placeholder={placeholder}
    helperText={helperMsg}
    error={isErr}
    {...props} />);
};

BaseTextField.propTypes = {
  placeholder: PropTypes.string,
  helperText: PropTypes.string,
  helperTextOff: PropTypes.bool,
  innerState: PropTypes.object,
  messages: PropTypes.object,
};

const TextField = ({ format, type, ...props }) =>
  (type === 'phone' ?
    <NumberFormat
      customInput={BaseTextField}
      {...props}
      mask="_"
      format="+7(###) ### - ####"
      placeholder="+7(___) ___ - ____" /> :
    <BaseTextField type={type} {...props} />);

export default TextField;
